.. include:: ../BADGES.rst

Python API Function Summary
===========================

.. autosummary::
    :toctree: _function_autosummary

    plottoolbox.plottoolbox.about
    plottoolbox.plottoolbox.autocorrelation
    plottoolbox.plottoolbox.barh
    plottoolbox.plottoolbox.barh_stacked
    plottoolbox.plottoolbox.bar
    plottoolbox.plottoolbox.bar_stacked
    plottoolbox.plottoolbox.bootstrap
    plottoolbox.plottoolbox.boxplot
    plottoolbox.plottoolbox.double_mass
    plottoolbox.plottoolbox.heatmap
    plottoolbox.plottoolbox.histogram
    plottoolbox.plottoolbox.kde
    plottoolbox.plottoolbox.kde_time
    plottoolbox.plottoolbox.lag_plot
    plottoolbox.plottoolbox.lognorm_xaxis
    plottoolbox.plottoolbox.lognorm_yaxis
    plottoolbox.plottoolbox.norm_xaxis
    plottoolbox.plottoolbox.norm_yaxis
    plottoolbox.plottoolbox.probability_density
    plottoolbox.plottoolbox.scatter_matrix
    plottoolbox.plottoolbox.target
    plottoolbox.plottoolbox.taylor
    plottoolbox.plottoolbox.time
    plottoolbox.plottoolbox.weibull_xaxis
    plottoolbox.plottoolbox.weibull_yaxis
    plottoolbox.plottoolbox.xy
